@@ -25,7 +25,11 @@ control_race <-
            extract = NULL, save_pred = FALSE,
            burn_in = 3, num_ties = 10, alpha = 0.05, randomize = TRUE,
            pkgs = NULL, save_workflow = FALSE, event_level = "first",
-           parallel_over = "everything") {
+           parallel_over = "everything", backend_options = NULL) {
+
+    # Any added arguments should also be added in superset control functions
+    # in other package. In other words, if tune_grid adds an option, the same
+    # object should be added here (regardless)
 
     tune::val_class_and_single(verbose,       "logical",   "control_race()")
     tune::val_class_and_single(verbose_elim,  "logical",   "control_race()")
@@ -64,7 +68,8 @@ control_race <-
       pkgs = pkgs,
       save_workflow = save_workflow,
       parallel_over = parallel_over,
-      event_level = event_level
+      event_level = event_level,
+      backend_options = backend_options
     )
 
     class(res) <- c("control_race")
