@@ -10,7 +10,8 @@ test_that("formula interface", {
       )
   })
   expect_equal(class(res), c("tune_race", "tune_results", "tbl_df", "tbl", "data.frame"))
-  expect_true(nrow(collect_metrics(res)) == nrow(grid_mod) * 2)
+  expect_true(nrow(collect_metrics(res)) < nrow(grid_mod) * 2)
+  expect_equal(res, .Last.tune.result)
 })
 
 # ------------------------------------------------------------------------------
@@ -26,7 +27,8 @@ test_that("recipe interface", {
       )
   })
   expect_equal(class(res), c("tune_race", "tune_results", "tbl_df", "tbl", "data.frame"))
-  expect_true(nrow(collect_metrics(res)) == nrow(grid_mod_rec) * 2)
+  expect_true(nrow(collect_metrics(res)) < nrow(grid_mod) * 2)
+  expect_equal(res, .Last.tune.result)
 })
 
 # ------------------------------------------------------------------------------
@@ -42,7 +44,8 @@ test_that("variable interface", {
       )
   })
   expect_equal(class(res), c("tune_race", "tune_results", "tbl_df", "tbl", "data.frame"))
-  expect_true(nrow(collect_metrics(res)) == nrow(grid_mod) * 2)
+  expect_true(nrow(collect_metrics(res))  < nrow(grid_mod) * 2)
+  expect_equal(res, .Last.tune.result)
 })
 
 # ------------------------------------------------------------------------------
